package Dist::Zilla::Role::StubBuild;
# ABSTRACT: provides an empty BUILD methods
$Dist::Zilla::Role::StubBuild::VERSION = '6.004'; # TRIAL
use Moose::Role;

sub BUILD {}

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Dist::Zilla::Role::StubBuild - provides an empty BUILD methods

=head1 VERSION

version 6.004

=head1 AUTHOR

Ricardo SIGNES 🎃 <rjbs@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2016 by Ricardo SIGNES.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
